summaryrefslogtreecommitdiff
path: root/wx+/dc.h
diff options
context:
space:
mode:
authorB. Stack <bgstack15@gmail.com>2022-08-03 08:51:28 -0400
committerB. Stack <bgstack15@gmail.com>2022-08-03 08:51:28 -0400
commit94e0c9205e6049c6b3295145af7fd39156e77543 (patch)
treec36c0f0c5fab7aa60432e9e1d32ba5fdfabeb55e /wx+/dc.h
parentMerge branch '11.22' into 'master' (diff)
downloadFreeFileSync-94e0c9205e6049c6b3295145af7fd39156e77543.tar.gz
FreeFileSync-94e0c9205e6049c6b3295145af7fd39156e77543.tar.bz2
FreeFileSync-94e0c9205e6049c6b3295145af7fd39156e77543.zip
add upstream 11.23
Diffstat (limited to 'wx+/dc.h')
-rw-r--r--wx+/dc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/wx+/dc.h b/wx+/dc.h
index c93715c2..e22820a7 100644
--- a/wx+/dc.h
+++ b/wx+/dc.h
@@ -126,12 +126,12 @@ int getDpiScalePercent()
inline
-wxBitmapBundle toBitmapBundle(const wxImage& img /*expected to be DPI-scaled!*/)
+wxBitmap toScaledBitmap(const wxImage& img /*expected to be DPI-scaled!*/)
{
//return wxBitmap(img, -1 /*depth*/, static_cast<double>(getDPI()) / defaultDpi); implementation just ignores scale parameter! WTF!
wxBitmap bmpScaled(img);
bmpScaled.SetScaleFactor(getDisplayScaleFactor());
- return bmpScaled;
+ return bmpScaled; //when testing use 175% scaling: wxWidgets' scaling logic doesn't kick in for 150% only
}
bgstack15
@@ -126,12 +126,12 @@ int getDpiScalePercent()
{
- //return wxBitmap(img, -1 /*depth*/, static_cast<double>(getDPI()) / defaultDpi); implementation just ignores scale parameter! WTF!
+ //wxBitmap(const wxImage& image, int depth = -1, double WXUNUSED(scale) = 1.0) => wxWidgets just ignores scale parameter! WTF!
wxBitmap bmpScaled(img);
bmpScaled.SetScaleFactor(getDisplayScaleFactor());